<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use DB;
use OhMyBrew\ShopifyApp\Facades\ShopifyApp;
use Config;
use App\Model\QuizModel;

class QuizController extends Controller
{
    private $domain;
    private $shop;
    private $quizModel;

     /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        date_default_timezone_set('America/Los_Angeles');
        $this->domain = env('SHOP_DOMAIN', true);
        $this->shop = ShopifyApp::shop($this->domain);
        $this->quizModel = new QuizModel();
    }
    public function getQuizDetails()
    {
        $customerID = isset($_REQUEST['id']) ? $_REQUEST['id'] : '';
        $params = [];

        $customerDetails = $this->shop->api()->rest('GET', '/admin/customers/'.$customerID.'.json', $params);
        $customerDetails = $customerDetails->body;
        $email = isset($customerDetails->customer->email) ? $customerDetails->customer->email : '';
        $firstName = isset($customerDetails->customer->first_name) ? $customerDetails->customer->first_name : '';
        $lastName = isset($customerDetails->customer->last_name) ? $customerDetails->customer->last_name : '';
        $customerName = $firstName." ".$lastName;

        $sessionIDs = $this->quizModel->getSessionID($email);

        $sessionIDs = $this->formatSessionID($sessionIDs);

        if (!empty($sessionIDs)) {
            $quizDetails = $this->quizModel->getQuizDetails($sessionIDs);
            //echo"<pre>"; print_r($quizDetails);die('test');
        }

        return view('customerQuiz',
            [
                "customerName" => $customerName,
                "email" => $email,
                "quizCount" => isset($quizDetails) ? count($quizDetails) : 0,
                "quizDetails" => isset($quizDetails) ? $quizDetails : '',
            ]
        );
    }

    public function formatData($quizDetails)
    {
        $quizArray = [];
        if (!empty($quizDetails)) {
            foreach ($quizDetails as $quziData) {
                if (!isset($quizArray[$quziData->question])) {
                    $quizArray[$quziData->question] = $quziData->response;
                }
                else {
                    $data = $quizArray[$quziData->question] . " | " . $quziData->response;
                    $quizArray[$quziData->question] = $data;
                }
            }
        }
        return $quizArray;
    }

    public function formatSessionID($sessionIDs)
    {

        $sessionID = '';
        if (!empty($sessionIDs)) {
            foreach ($sessionIDs as $value) {
                $sessionID .= $value->session_id . ",";
            }
        }

        return rtrim($sessionID, ",");
    }

    public function getQuizDetailById()
    {

        $sessionID = isset($_REQUEST['sessionId']) ? $_REQUEST['sessionId'] : '';
        $email = isset($_REQUEST['email']) ? $_REQUEST['email'] : '';

        if (empty($sessionID)) {
            // $email = 'testing+TestUser@p80w.com';
            $sessionID = $this->quizModel->getSessionIds($email);  // TODO
        }
       
        $quizDetails = $this->quizModel->getQuizDetails($sessionID);
       
        $recommendations = $this->quizModel->getRecommendation($sessionID);

        return view('quizDetails',
            [
                "quizDetails" => $quizDetails[$sessionID],
                "sessionId" => $sessionID,
                "recommendation" => !empty($recommendations) ? json_decode($recommendations) : ''
            ]
        );

    }

    public function getCustomerDetails()
    {
        $email = isset($_REQUEST['email']) ? $_REQUEST['email'] : '';
        $customerName = isset($_REQUEST['name']) ? $_REQUEST['name'] : '';
        $sessionID = $this->quizModel->getSessionIds($email);  // TODO
        
        if (!empty($sessionID)) {
            $quizDetails = $this->quizModel->getQuizDetails($sessionID);
        }

        return view('customerQuiz',
            [
               
                "customerName" => $customerName,
                "email" => $email,
                "quizCount" => isset($quizDetails) ? count($quizDetails) : 0,
                "quizDetails" => isset($quizDetails) ? $quizDetails : '',
            ]
        );

    }

    public function quizList()
    {

        $limit = 20;
        $previousLink = '';
        $nextLink = '';
        $getPageLink = '';

        if (!isset($_GET['page'])) {
            $data = $this->shop->api()->rest('GET', '/admin/api/2020-04/customers.json', ["fields" => "email,first_name, last_name", "limit" => $limit]);
            $previousLink = !empty($data->link->previous)? $previousLink = $data->link->previous:'';
            $nextLink = !empty($data->link->next)? $nextLink = $data->link->next:'';
        } else {
            $getPageLink = trim($_GET['page']);
            $data = $this->shop->api()->rest('GET', '/admin/api/2020-04/customers.json', ["limit" => $limit,
            'page_info' => $getPageLink]);

            $previousLink = !empty($data->link->previous)? $previousLink = $data->link->previous:'';
            $nextLink = !empty($data->link->next)? $nextLink = $data->link->next:'';
        }

        $customerData = [];
        $customerEmail = [];
        foreach ($data->body->customers as $customer) {
            $email = $customer->email;
            $name = $customer->first_name." ".$customer->last_name;
            $temp = array("email" => $email, "name" => $name);
            $customerData[] = $temp;
            $customerEmail[] = $email;
        }

        $emails = '"' . implode('","', $customerEmail) . '"';

        $quizDetails = $this->quizModel->getQuizDetailsByEmail($emails);

        return view('welcome', [
            "customers" => $customerData,
            "quizDetails" => $quizDetails,
            "previousLink" => $previousLink,
            "nextLink" => $nextLink
        ]);
    }
}
